@@ -76,7 +76,8 @@ def repo_name(wid, cid):
 
 class Asset:
     def __init__(self, path):
-        path_parts = path.split("/")
+        self.path = path
+        path_parts = self.path.split("/")
         self.id = path_parts[-1]
         self.type = path_parts[-2]
         if len(path_parts) > 2:
